@@ -2,10 +2,10 @@ package Mojolicious::Plugin::TtRenderer;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.59'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -38,7 +38,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.56
+version 1.59
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,8 @@ L<Mojolicious::Plugin::TtRenderer::Engine> directly.
 =for stopwords Bjørn
 Szász
 Árpád
+Романов
+Сергей
 
 =head1 OPTIONS
 
@@ -231,8 +233,6 @@ L<Mojolicious>,
 L<Mojolicious::Guides>, 
 L<http://mojolicious.org>.
 
-=cut
-
 =head1 AUTHOR
 
 Original author: Ask Bjørn Hansen
@@ -273,9 +273,11 @@ uwisser
 
 Dinis Lage
 
+jay mortensen (GMORTEN)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ask Bjørn Hansen.
+This software is copyright (c) 2017 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
